@@ -852,8 +852,9 @@ public abstract class SocketClient
      *
      * @return the charset.
      * @since 3.3
-     * TODO Will be deprecated once the code requires Java 1.6 as a mininmum
+     * @deprecated Since the code now requires Java 1.6 as a mininmum
      */
+    @Deprecated
     public String getCharsetName() {
         return charset.name();
     }
