@@ -27,7 +27,7 @@ import org.apache.commons.net.ftp.FTPFile;
  * Implementation of FTPFileEntryParser and FTPFileListParser for IBM zOS/MVS
  * Systems.
  *
- * @version $Id: MVSFTPEntryParser.java 1697293 2015-08-24 01:01:00Z sebb $
+ * @version $Id: MVSFTPEntryParser.java 1741829 2016-05-01 00:24:44Z sebb $
  * @see org.apache.commons.net.ftp.FTPFileEntryParser FTPFileEntryParser (for
  *      usage instructions)
  */
@@ -55,9 +55,11 @@ public class MVSFTPEntryParser extends ConfigurableFTPFileEntryParserImpl {
                                                                     // 13:52
 
     /**
-     * Matches these entries: Volume Unit Referred Ext Used Recfm Lrecl BlkSz
-     * Dsorg Dsname B10142 3390 2006/03/20 2 31 F 80 80 PS MDI.OKL.WORK
-     *
+     * Matches these entries:
+     * <pre>
+     *  Volume Unit    Referred Ext Used Recfm Lrecl BlkSz Dsorg Dsname
+     *  B10142 3390   2006/03/20  2   31  F       80    80  PS   MDI.OKL.WORK
+     * </pre>
      */
     static final String FILE_LIST_REGEX = "\\S+\\s+" + // volume
                                                                 // ignored
@@ -73,8 +75,11 @@ public class MVSFTPEntryParser extends ConfigurableFTPFileEntryParserImpl {
             "(\\S+)\\s*"; // Dataset Name (file name)
 
     /**
-     * Matches these entries: Name VV.MM Created Changed Size Init Mod Id
-     * TBSHELF 01.03 2002/09/12 2002/10/11 09:37 11 11 0 KIL001
+     * Matches these entries:
+     * <pre>
+     *   Name      VV.MM   Created       Changed      Size  Init   Mod   Id
+     *   TBSHELF   01.03 2002/09/12 2002/10/11 09:37    11    11     0 KIL001
+     * </pre>
      */
     static final String MEMBER_LIST_REGEX = "(\\S+)\\s+" + // name
             "\\S+\\s+" + // version, modification (ignored)
@@ -87,12 +92,15 @@ public class MVSFTPEntryParser extends ConfigurableFTPFileEntryParserImpl {
             "\\S+\\s*"; // id of user who modified (ignored)
 
     /**
-     * Matches these entries, note: no header: IBMUSER1 JOB01906 OUTPUT 3 Spool
-     * Files 012345678901234567890123456789012345678901234 1 2 3 4
+     * Matches these entries, note: no header:
+     * <pre>
+     *   IBMUSER1  JOB01906  OUTPUT    3 Spool Files
+     *   012345678901234567890123456789012345678901234
+     *             1         2         3         4
+     * </pre>
      */
-    static final String JES_LEVEL_1_LIST_REGEX = "(\\S+)\\s+" + // job
-                                                                        // name
-                                                                        // ignored
+    static final String JES_LEVEL_1_LIST_REGEX =
+            "(\\S+)\\s+" + // job name ignored
             "(\\S+)\\s+" + // job number
             "(\\S+)\\s+" + // job status (OUTPUT,INPUT,ACTIVE)
             "(\\S+)\\s+" + // number of spool files
@@ -101,16 +109,41 @@ public class MVSFTPEntryParser extends ConfigurableFTPFileEntryParserImpl {
     ;
 
     /**
-     * JES INTERFACE LEVEL 2 parser Matches these entries: JOBNAME JOBID OWNER
-     * STATUS CLASS IBMUSER1 JOB01906 IBMUSER OUTPUT A RC=0000 3 spool files
-     * IBMUSER TSU01830 IBMUSER OUTPUT TSU ABEND=522 3 spool files
-     * 012345678901234567890123456789012345678901234 1 2 3 4
-     * 012345678901234567890123456789012345678901234567890
+     * JES INTERFACE LEVEL 2 parser
+     * Matches these entries:
+     * <pre>
+     * JOBNAME  JOBID    OWNER    STATUS CLASS
+     * IBMUSER1 JOB01906 IBMUSER  OUTPUT A        RC=0000 3 spool files
+     * IBMUSER  TSU01830 IBMUSER  OUTPUT TSU      ABEND=522 3 spool files
+     * </pre>
+     * Sample output from FTP session:
+     * <pre>
+     * ftp> quote site filetype=jes
+     * 200 SITE command was accepted
+     * ftp> ls
+     * 200 Port request OK.
+     * 125 List started OK for JESJOBNAME=IBMUSER*, JESSTATUS=ALL and JESOWNER=IBMUSER
+     * JOBNAME  JOBID    OWNER    STATUS CLASS
+     * IBMUSER1 JOB01906 IBMUSER  OUTPUT A        RC=0000 3 spool files
+     * IBMUSER  TSU01830 IBMUSER  OUTPUT TSU      ABEND=522 3 spool files
+     * 250 List completed successfully.
+     * ftp> ls job01906
+     * 200 Port request OK.
+     * 125 List started OK for JESJOBNAME=IBMUSER*, JESSTATUS=ALL and JESOWNER=IBMUSER
+     * JOBNAME  JOBID    OWNER    STATUS CLASS
+     * IBMUSER1 JOB01906 IBMUSER  OUTPUT A        RC=0000
+     * --------
+     * ID  STEPNAME PROCSTEP C DDNAME   BYTE-COUNT
+     * 001 JES2              A JESMSGLG       858
+     * 002 JES2              A JESJCL         128
+     * 003 JES2              A JESYSMSG       443
+     * 3 spool files
+     * 250 List completed successfully.
+     * </pre>
      */
 
-    static final String JES_LEVEL_2_LIST_REGEX = "(\\S+)\\s+" + // job
-                                                                        // name
-                                                                        // ignored
+    static final String JES_LEVEL_2_LIST_REGEX =
+            "(\\S+)\\s+" + // job name ignored
             "(\\S+)\\s+" + // job number
             "(\\S+)\\s+" + // owner ignored
             "(\\S+)\\s+" + // job status (OUTPUT,INPUT,ACTIVE) ignored
@@ -225,7 +258,7 @@ public class MVSFTPEntryParser extends ConfigurableFTPFileEntryParserImpl {
      *            A line of text from the file listing
      * @return An FTPFile instance corresponding to the supplied entry
      */
-//    @Override
+    @Override
     public FTPFile parseFTPEntry(String entry) {
         boolean isParsed = false;
         FTPFile f = new FTPFile();
@@ -305,16 +338,23 @@ public class MVSFTPEntryParser extends ConfigurableFTPFileEntryParserImpl {
     /**
      * Parse entries within a partitioned dataset.
      *
-     * Format of a memberlist within a PDS: 1 2 3 4 5 6 7 8 9 Name VV.MM Created
-     * Changed Size Init Mod Id TBSHELF 01.03 2002/09/12 2002/10/11 09:37 11 11
-     * 0 KIL001 TBTOOL 01.12 2002/09/12 2004/11/26 19:54 51 28 0 KIL001
-     *
-     * ------------------------------------------- [1] Name [2] VV.MM: Version .
-     * modification [3] Created: yyyy / MM / dd [4,5] Changed: yyyy / MM / dd
-     * HH:mm [6] Size: number of lines [7] Init: number of lines when first
-     * created [8] Mod: number of modified lines a last save [9] Id: User id for
-     * last update
+     * Format of a memberlist within a PDS:
+     * <pre>
+     *    0         1        2          3        4     5     6      7    8
+     *   Name      VV.MM   Created       Changed      Size  Init   Mod   Id
+     *   TBSHELF   01.03 2002/09/12 2002/10/11 09:37    11    11     0 KIL001
+     *   TBTOOL    01.12 2002/09/12 2004/11/26 19:54    51    28     0 KIL001
      *
+     * -------------------------------------------
+     * [1] Name
+     * [2] VV.MM: Version . modification
+     * [3] Created: yyyy / MM / dd
+     * [4,5] Changed: yyyy / MM / dd HH:mm
+     * [6] Size: number of lines
+     * [7] Init: number of lines when first created
+     * [8] Mod: number of modified lines a last save
+     * [9] Id: User id for last update
+     * </pre>
      *
      * @param file
      *            will be updated with Name, Type and Timestamp if parsed.
@@ -378,13 +418,20 @@ public class MVSFTPEntryParser extends ConfigurableFTPFileEntryParserImpl {
     }
 
     /**
-     * Matches these entries, note: no header: [1] [2] [3] [4] [5] IBMUSER1
-     * JOB01906 OUTPUT 3 Spool Files
-     * 012345678901234567890123456789012345678901234 1 2 3 4
-     * ------------------------------------------- Group in regex [1] Job name
-     * [2] Job number [3] Job status (INPUT,ACTIVE,OUTPUT) [4] Number of sysout
-     * files [5] The string "Spool Files"
-     *
+     * Matches these entries, note: no header:
+     * <pre>
+     * [1]      [2]      [3]   [4] [5]
+     * IBMUSER1 JOB01906 OUTPUT 3 Spool Files
+     * 012345678901234567890123456789012345678901234
+     *           1         2         3         4
+     * -------------------------------------------
+     * Group in regex
+     * [1] Job name
+     * [2] Job number
+     * [3] Job status (INPUT,ACTIVE,OUTPUT)
+     * [4] Number of sysout files
+     * [5] The string "Spool Files"
+     *</pre>
      *
      * @param file
      *            will be updated with Name, Type and Timestamp if parsed.
@@ -406,14 +453,23 @@ public class MVSFTPEntryParser extends ConfigurableFTPFileEntryParserImpl {
     }
 
     /**
-     * Matches these entries, note: no header: [1] [2] [3] [4] [5] JOBNAME JOBID
-     * OWNER STATUS CLASS IBMUSER1 JOB01906 IBMUSER OUTPUT A RC=0000 3 spool
-     * files IBMUSER TSU01830 IBMUSER OUTPUT TSU ABEND=522 3 spool files
-     * 012345678901234567890123456789012345678901234 1 2 3 4
-     * ------------------------------------------- Group in regex [1] Job name
-     * [2] Job number [3] Owner [4] Job status (INPUT,ACTIVE,OUTPUT) [5] Job
-     * Class [6] The rest
-     *
+     * Matches these entries:
+     * <pre>
+     * [1]      [2]      [3]     [4]    [5]
+     * JOBNAME  JOBID    OWNER   STATUS CLASS
+     * IBMUSER1 JOB01906 IBMUSER OUTPUT A       RC=0000 3 spool files
+     * IBMUSER  TSU01830 IBMUSER OUTPUT TSU     ABEND=522 3 spool files
+     * 012345678901234567890123456789012345678901234
+     *           1         2         3         4
+     * -------------------------------------------
+     * Group in regex
+     * [1] Job name
+     * [2] Job number
+     * [3] Owner
+     * [4] Job status (INPUT,ACTIVE,OUTPUT)
+     * [5] Job Class
+     * [6] The rest
+     * </pre>
      *
      * @param file
      *            will be updated with Name, Type and Timestamp if parsed.
@@ -436,8 +492,11 @@ public class MVSFTPEntryParser extends ConfigurableFTPFileEntryParserImpl {
 
     /**
      * preParse is called as part of the interface. Per definition is is called
-     * before the parsing takes place. Three kind of lists is recognize:
-     * z/OS-MVS File lists z/OS-MVS Member lists unix file lists
+     * before the parsing takes place.
+     * Three kind of lists is recognize:
+     * z/OS-MVS File lists
+     * z/OS-MVS Member lists
+     * unix file lists
      * @since 2.0
      */
     @Override
