@@ -271,7 +271,7 @@ public class TFTPServer implements Runnable
         return !shutdownServer;
     }
 
-//    @Override
+    @Override
     public void run()
     {
         try
@@ -373,7 +373,7 @@ public class TFTPServer implements Runnable
             }
         }
 
-//        @Override
+        @Override
         public void run()
         {
             try
